@@ -1,9 +1,9 @@
 package Music::ModalFunction;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Inspect musical modal functions
+# ABSTRACT: Query for modal and scalar musical functions
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use strictures 2;
 use AI::Prolog ();
@@ -56,7 +56,7 @@ sub _build__modes {
             { chord => 'dim', roman => 'r_vii', function => 'leading_tone' },
         ],
         dorian => [
-            { chord => 'min', roman => 'r_i',   function => 'tonic' },
+            { chord => 'min', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'min', roman => 'r_ii',  function => 'supertonic' },
             { chord => 'maj', roman => 'r_III', function => 'mediant' },
             { chord => 'maj', roman => 'r_IV',  function => 'subdominant' },
@@ -65,7 +65,7 @@ sub _build__modes {
             { chord => 'maj', roman => 'r_VII', function => 'subtonic' },
         ],
         phrygian => [
-            { chord => 'min', roman => 'r_i',   function => 'tonic' },
+            { chord => 'min', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'maj', roman => 'r_II',  function => 'supertonic' },
             { chord => 'maj', roman => 'r_III', function => 'mediant' },
             { chord => 'min', roman => 'r_iv',  function => 'subdominant' },
@@ -92,7 +92,7 @@ sub _build__modes {
             { chord => 'maj', roman => 'r_VII', function => 'subtonic' },
         ],
         aeolian => [
-            { chord => 'min', roman => 'r_i',   function => 'tonic' },
+            { chord => 'min', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'dim', roman => 'r_ii',  function => 'supertonic' },
             { chord => 'maj', roman => 'r_III', function => 'mediant' },
             { chord => 'min', roman => 'r_iv',  function => 'subdominant' },
@@ -101,7 +101,7 @@ sub _build__modes {
             { chord => 'maj', roman => 'r_VII', function => 'subtonic' },
         ],
         locrian => [
-            { chord => 'dim', roman => 'r_i',   function => 'tonic' },
+            { chord => 'dim', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'maj', roman => 'r_II',  function => 'supertonic' },
             { chord => 'min', roman => 'r_iii', function => 'mediant' },
             { chord => 'min', roman => 'r_iv',  function => 'subdominant' },
@@ -115,7 +115,7 @@ sub _build__modes {
 sub _build__scales {
     return {
         harmonic_minor => [
-            { chord => 'min', roman => 'r_i',   function => 'tonic' },
+            { chord => 'min', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'dim', roman => 'r_ii',  function => 'supertonic' },
             { chord => 'aug', roman => 'r_III', function => 'mediant' },
             { chord => 'min', roman => 'r_iv',  function => 'subdominant' },
@@ -124,7 +124,7 @@ sub _build__scales {
             { chord => 'dim', roman => 'r_vii', function => 'subtonic' },
         ],
         melodic_minor => [
-            { chord => 'min', roman => 'r_i',   function => 'tonic' },
+            { chord => 'min', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'min', roman => 'r_ii',  function => 'supertonic' },
             { chord => 'aug', roman => 'r_III', function => 'mediant' },
             { chord => 'maj', roman => 'r_IV',  function => 'subdominant' },
@@ -140,14 +140,14 @@ sub _build__scales {
             { chord => 'min', roman => 'r_vi',  function => 'submediant' },
         ],
         pentatonic_minor => [
-            { chord => 'min', roman => 'r_i',   function => 'tonic' },
+            { chord => 'min', roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'dim', roman => 'r_ii',  function => 'supertonic' },
             { chord => 'min', roman => 'r_iv',  function => 'subdominant' },
             { chord => 'min', roman => 'r_v',   function => 'dominant' },
             { chord => 'maj', roman => 'r_VI',  function => 'submediant' },
         ],
         blues => [
-            { chord => 'min',  roman => 'r_i',   function => 'tonic' },
+            { chord => 'min',  roman => 'r_i',   function => 'parallel_minor' },
             { chord => 'maj',  roman => 'r_III', function => 'supertonic' },
             { chord => 'sus4', roman => 'r_IV',  function => 'subdominant' },
             { chord => 'maj',  roman => 'r_bV',  function => 'flat5' },
@@ -156,7 +156,7 @@ sub _build__scales {
         ],
         diminished => [
             { chord => 'maj', roman => 'r_I',    function => 'tonic' },
-            { chord => 'dim', roman => 'r_bII',  function => 'flat2' },
+            { chord => 'dim', roman => 'r_bii',  function => 'flat2' },
             { chord => 'maj', roman => 'r_bIII', function => 'flat3' },
             { chord => 'dim', roman => 'r_iii',  function => 'mediant' },
             { chord => 'maj', roman => 'r_bV',   function => 'flat5' },
@@ -329,11 +329,11 @@ __END__
 
 =head1 NAME
 
-Music::ModalFunction - Inspect musical modal functions
+Music::ModalFunction - Query for modal and scalar musical functions
 
 =head1 VERSION
 
-version 0.0503
+version 0.0504
 
 =head1 SYNOPSIS
 
@@ -341,19 +341,19 @@ version 0.0503
 
   # What chords do C major and A minor have in common?
   my $m = Music::ModalFunction->new(
-    mode_note    => 'c',
-    mode         => 'ionian',
-    key_note     => 'a',
-    key          => 'aeolian',
+    mode_note => 'c',
+    mode      => 'ionian',
+    key_note  => 'a',
+    key       => 'aeolian',
   );
   my $results = $m->pivot_chord_keys; # 7 common chords
 
   # What chords do C major and F♯ (G♭) major have in common?
   $m = Music::ModalFunction->new(
-    mode_note    => 'c',
-    mode         => 'ionian',
-    key_note     => 'gb',
-    key          => 'ionian',
+    mode_note => 'c',
+    mode      => 'ionian',
+    key_note  => 'gb',
+    key       => 'ionian',
   );
   $results = $m->pivot_chord_keys; # No chords in common!
 
@@ -391,7 +391,7 @@ version 0.0503
       use_scales => 1,
   );
   $results = $m->pivot_chord_keys;
-  # [ 'pivot_chord_keys', 'd', 'dim', 'c', 'diminished', 'flat2', 'r_bII', 'c', 'harmonic_minor', 'supertonic', 'r_ii' ],
+  # [ 'pivot_chord_keys', 'd', 'dim', 'c', 'diminished', 'flat2', 'r_bii', 'c', 'harmonic_minor', 'supertonic', 'r_ii' ],
   # [ 'pivot_chord_keys', 'b', 'dim', 'c', 'diminished', 'leading_tone', 'r_vii', 'c', 'harmonic_minor', 'subtonic', 'r_vii' ],
 
 =head1 DESCRIPTION
@@ -421,7 +421,8 @@ chose to use "key" even though that is confusing. Argh! :|
 
 =head2 chord_note, mode_note, key_note
 
-C<c>, C<db>, C<d>, C<eb>, C<e>, C<f>, C<gb>, C<g>, C<ab>, C<a>, C<bb>, or C<b>
+C<c>, C<db>, C<d>, C<eb>, C<e>, C<f>, C<gb>, C<g>, C<ab>, C<a>, C<bb>,
+or C<b>
 
 * Sharps are not used - only flats.
 
@@ -431,15 +432,20 @@ C<maj>, C<min>, or C<dim>
 
 =head2 mode, key
 
-C<ionian>, C<dorian>, C<phrygian>, C<lydian>, C<mixolydian>, C<aeolian>, or C<locrian>
+C<ionian>, C<dorian>, C<phrygian>, C<lydian>, C<mixolydian>,
+C<aeolian>, or C<locrian>
 
 =head2 mode_function, key_function
 
-C<tonic>, C<supertonic>, C<mediant>, C<subdominant>, C<dominant>, C<submediant>, C<leading_tone>, or C<subtonic>
+C<tonic>, C<parallel_minor>, C<flat2>, C<supertonic>, C<flat3>,
+C<mediant>, C<subdominant>, C<flat5>, C<dominant>, C<submediant>,
+C<leading_tone>, or C<subtonic>
 
 =head2 mode_roman, key_roman
 
-C<r_I>, C<r_ii>, C<r_iii>, C<r_IV>, C<r_V>, C<r_vi>, or C<r_vii>
+C<r_I>, C<r_i>, C<r_bii>, C<r_II>, C<r_ii>, C<r_bIII>, C<r_III>,
+C<r_iii>, C<r_IV>, C<r_bV>, C<r_V>, C<r_v>, C<r_VI>, C<r_vi>,
+C<r_vii>, or C<r_VII>.
 
 =head2 hash_results
 
